==> jc-1.4.0.tar.gz: gnu/java/nio/SelectionKeyImpl.h <==
// public abstract class gnu.java.nio.SelectionKeyImpl

// class file dependencies
// @dep_class b28d29aeeb71c32a gnu_java_nio_SelectionKeyImpl
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 78dea1137fb244b3 java_nio_channels_SelectionKey
// @dep_class c9ba919e4c66ad44 java_nio_channels_spi_AbstractSelectionKey

// header file dependencies
// @dep_header java_nio_channels_spi_AbstractSelectionKey

#include "java/nio/channels/spi/AbstractSelectionKey.h"

#ifndef _JC_gnu_java_nio_SelectionKeyImpl_H_
#define _JC_gnu_java_nio_SelectionKeyImpl_H_

// Forward structure declarations
struct _jc_gnu_java_nio_SelectorImpl$object;
struct _jc_java_lang_Class$object;
struct _jc_java_nio_channels_SelectableChannel$object;
struct _jc_java_nio_channels_SelectionKey$object;
struct _jc_java_nio_channels_Selector$object;

// Typedefs
typedef struct _jc_gnu_java_nio_SelectionKeyImpl$sub_refs	_jc_gnu_java_nio_SelectionKeyImpl$sub_refs;
typedef struct _jc_gnu_java_nio_SelectionKeyImpl$sub_nonrefs	_jc_gnu_java_nio_SelectionKeyImpl$sub_nonrefs;
typedef struct _jc_gnu_java_nio_SelectionKeyImpl$refs	_jc_gnu_java_nio_SelectionKeyImpl$refs;
typedef struct _jc_gnu_java_nio_SelectionKeyImpl$nonrefs	_jc_gnu_java_nio_SelectionKeyImpl$nonrefs;
typedef struct _jc_gnu_java_nio_SelectionKeyImpl$object	_jc_gnu_java_nio_SelectionKeyImpl$object;

typedef const struct _jc_gnu_java_nio_SelectionKeyImpl$vmethods	_jc_gnu_java_nio_SelectionKeyImpl$vmethods;
typedef const struct _jc_gnu_java_nio_SelectionKeyImpl$vtable	_jc_gnu_java_nio_SelectionKeyImpl$vtable;
typedef const struct _jc_gnu_java_nio_SelectionKeyImpl$vtype	_jc_gnu_java_nio_SelectionKeyImpl$vtype;

// Constructors
extern void _jc_gnu_java_nio_SelectionKeyImpl$method$_init$84edc5c308faeb62(_jc_env *, struct _jc_gnu_java_nio_SelectionKeyImpl$object *, struct _jc_java_nio_channels_SelectableChannel$object *, struct _jc_gnu_java_nio_SelectorImpl$object *);

// Virtual methods
extern struct _jc_java_nio_channels_SelectableChannel$object *_jc_gnu_java_nio_SelectionKeyImpl$method$channel$e64fdc027b0f082f(_jc_env *, struct _jc_gnu_java_nio_SelectionKeyImpl$object *);
extern jint _jc_gnu_java_nio_SelectionKeyImpl$method$getNativeFD$4ed008ed25fb0a89(_jc_env *, struct _jc_gnu_java_nio_SelectionKeyImpl$object *);
extern jint _jc_gnu_java_nio_SelectionKeyImpl$method$interestOps$03e920958ba95510(_jc_env *, struct _jc_gnu_java_nio_SelectionKeyImpl$object *);
extern struct _jc_java_nio_channels_SelectionKey$object *_jc_gnu_java_nio_SelectionKeyImpl$method$interestOps$0d8b00b560cc9fa0(_jc_env *, struct _jc_gnu_java_nio_SelectionKeyImpl$object *, jint);
extern jint _jc_gnu_java_nio_SelectionKeyImpl$method$readyOps$a69042b12a540927(_jc_env *, struct _jc_gnu_java_nio_SelectionKeyImpl$object *);
extern struct _jc_java_nio_channels_SelectionKey$object *_jc_gnu_java_nio_SelectionKeyImpl$method$readyOps$ac2951c8f6f38728(_jc_env *, struct _jc_gnu_java_nio_SelectionKeyImpl$object *, jint);
extern struct _jc_java_nio_channels_Selector$object *_jc_gnu_java_nio_SelectionKeyImpl$method$selector$d43640f937373599(_jc_env *, struct _jc_gnu_java_nio_SelectionKeyImpl$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_nio_SelectionKeyImpl$method_info$channel$e64fdc027b0f082f;
extern _jc_method _jc_gnu_java_nio_SelectionKeyImpl$method_info$getNativeFD$4ed008ed25fb0a89;
extern _jc_method _jc_gnu_java_nio_SelectionKeyImpl$method_info$interestOps$03e920958ba95510;
extern _jc_method _jc_gnu_java_nio_SelectionKeyImpl$method_info$interestOps$0d8b00b560cc9fa0;
extern _jc_method _jc_gnu_java_nio_SelectionKeyImpl$method_info$readyOps$a69042b12a540927;
extern _jc_method _jc_gnu_java_nio_SelectionKeyImpl$method_info$readyOps$ac2951c8f6f38728;
extern _jc_method _jc_gnu_java_nio_SelectionKeyImpl$method_info$selector$d43640f937373599;

// Virtual methods structure
struct _jc_gnu_java_nio_SelectionKeyImpl$vmethods {
	struct _jc_java_nio_channels_SelectableChannel$object	*(*channel$e64fdc027b0f082f)(_jc_env *, struct _jc_gnu_java_nio_SelectionKeyImpl$object *);
	jint	(*getNativeFD$4ed008ed25fb0a89)(_jc_env *, struct _jc_gnu_java_nio_SelectionKeyImpl$object *);
	jint	(*interestOps$03e920958ba95510)(_jc_env *, struct _jc_gnu_java_nio_SelectionKeyImpl$object *);
	struct _jc_java_nio_channels_SelectionKey$object	*(*interestOps$0d8b00b560cc9fa0)(_jc_env *, struct _jc_gnu_java_nio_SelectionKeyImpl$object *, jint);
	jint	(*readyOps$a69042b12a540927)(_jc_env *, struct _jc_gnu_java_nio_SelectionKeyImpl$object *);
	struct _jc_java_nio_channels_SelectionKey$object	*(*readyOps$ac2951c8f6f38728)(_jc_env *, struct _jc_gnu_java_nio_SelectionKeyImpl$object *, jint);
	struct _jc_java_nio_channels_Selector$object	*(*selector$d43640f937373599)(_jc_env *, struct _jc_gnu_java_nio_SelectionKeyImpl$object *);
};

// Vtable
struct _jc_gnu_java_nio_SelectionKeyImpl$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_channels_SelectionKey$vmethods	java_nio_channels_SelectionKey;
	_jc_java_nio_channels_spi_AbstractSelectionKey$vmethods	java_nio_channels_spi_AbstractSelectionKey;
	_jc_gnu_java_nio_SelectionKeyImpl$vmethods	gnu_java_nio_SelectionKeyImpl;
};

// Vtype
struct _jc_gnu_java_nio_SelectionKeyImpl$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_SelectionKeyImpl$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_SelectionKeyImpl$sub_refs {
	struct _jc_gnu_java_nio_SelectorImpl$object	*impl;
	struct _jc_java_nio_channels_SelectableChannel$object	*ch;
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_SelectionKeyImpl$refs {
    _jc_gnu_java_nio_SelectionKeyImpl$sub_refs	gnu_java_nio_SelectionKeyImpl;
    _jc_java_nio_channels_spi_AbstractSelectionKey$sub_refs	java_nio_channels_spi_AbstractSelectionKey;
    _jc_java_nio_channels_SelectionKey$sub_refs	java_nio_channels_SelectionKey;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_SelectionKeyImpl$sub_nonrefs {
	jint	readyOps;
	jint	interestOps;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_SelectionKeyImpl$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_channels_SelectionKey$sub_nonrefs	java_nio_channels_SelectionKey;
    _jc_java_nio_channels_spi_AbstractSelectionKey$sub_nonrefs	java_nio_channels_spi_AbstractSelectionKey;
    _jc_gnu_java_nio_SelectionKeyImpl$sub_nonrefs	gnu_java_nio_SelectionKeyImpl;
};

// Object instance structure
struct _jc_gnu_java_nio_SelectionKeyImpl$object {
	_jc_gnu_java_nio_SelectionKeyImpl$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_SelectionKeyImpl$vtype	*vtype;
	_jc_gnu_java_nio_SelectionKeyImpl$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_SelectionKeyImpl$vtype _jc_gnu_java_nio_SelectionKeyImpl$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_SelectionKeyImpl, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_SelectionKeyImpl$class_object;

#endif	/* _JC_gnu_java_nio_SelectionKeyImpl_H_ */

==> jc-1.4.6.tar.gz: gnu/java/nio/SelectionKeyImpl.h <==
// public abstract class gnu.java.nio.SelectionKeyImpl

// class file dependencies
// @dep_class b28d29aeeb71c32a gnu_java_nio_SelectionKeyImpl
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 78dea1137fb244b3 java_nio_channels_SelectionKey
// @dep_class c9ba919e4c66ad44 java_nio_channels_spi_AbstractSelectionKey

// header file dependencies
// @dep_header java_nio_channels_spi_AbstractSelectionKey

#include "java/nio/channels/spi/AbstractSelectionKey.h"

#ifndef _JC_gnu_java_nio_SelectionKeyImpl_H_
#define _JC_gnu_java_nio_SelectionKeyImpl_H_

// Forward structure declarations
struct _jc_gnu_java_nio_SelectorImpl$object;
struct _jc_java_lang_Class$object;
struct _jc_java_nio_channels_SelectableChannel$object;
struct _jc_java_nio_channels_SelectionKey$object;
struct _jc_java_nio_channels_Selector$object;

// Typedefs
typedef struct _jc_gnu_java_nio_SelectionKeyImpl$sub_refs	_jc_gnu_java_nio_SelectionKeyImpl$sub_refs;
typedef struct _jc_gnu_java_nio_SelectionKeyImpl$sub_nonrefs	_jc_gnu_java_nio_SelectionKeyImpl$sub_nonrefs;
typedef struct _jc_gnu_java_nio_SelectionKeyImpl$refs	_jc_gnu_java_nio_SelectionKeyImpl$refs;
typedef struct _jc_gnu_java_nio_SelectionKeyImpl$nonrefs	_jc_gnu_java_nio_SelectionKeyImpl$nonrefs;
typedef struct _jc_gnu_java_nio_SelectionKeyImpl$object	_jc_gnu_java_nio_SelectionKeyImpl$object;

typedef const struct _jc_gnu_java_nio_SelectionKeyImpl$vmethods	_jc_gnu_java_nio_SelectionKeyImpl$vmethods;
typedef const struct _jc_gnu_java_nio_SelectionKeyImpl$vtable	_jc_gnu_java_nio_SelectionKeyImpl$vtable;
typedef const struct _jc_gnu_java_nio_SelectionKeyImpl$vtype	_jc_gnu_java_nio_SelectionKeyImpl$vtype;

// Constructors
extern void _jc_gnu_java_nio_SelectionKeyImpl$method$_init$84edc5c308faeb62(_jc_env *, struct _jc_gnu_java_nio_SelectionKeyImpl$object *, struct _jc_java_nio_channels_SelectableChannel$object *, struct _jc_gnu_java_nio_SelectorImpl$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_nio_channels_SelectableChannel$object *_jc_gnu_java_nio_SelectionKeyImpl$method$channel$e64fdc027b0f082f(_jc_env *, struct _jc_gnu_java_nio_SelectionKeyImpl$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_nio_SelectionKeyImpl$method$getNativeFD$4ed008ed25fb0a89(_jc_env *, struct _jc_gnu_java_nio_SelectionKeyImpl$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_nio_SelectionKeyImpl$method$interestOps$03e920958ba95510(_jc_env *, struct _jc_gnu_java_nio_SelectionKeyImpl$object *) _JC_JCNI_ATTR;
extern struct _jc_java_nio_channels_SelectionKey$object *_jc_gnu_java_nio_SelectionKeyImpl$method$interestOps$0d8b00b560cc9fa0(_jc_env *, struct _jc_gnu_java_nio_SelectionKeyImpl$object *, jint) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_nio_SelectionKeyImpl$method$readyOps$a69042b12a540927(_jc_env *, struct _jc_gnu_java_nio_SelectionKeyImpl$object *) _JC_JCNI_ATTR;
extern struct _jc_java_nio_channels_SelectionKey$object *_jc_gnu_java_nio_SelectionKeyImpl$method$readyOps$ac2951c8f6f38728(_jc_env *, struct _jc_gnu_java_nio_SelectionKeyImpl$object *, jint) _JC_JCNI_ATTR;
extern struct _jc_java_nio_channels_Selector$object *_jc_gnu_java_nio_SelectionKeyImpl$method$selector$d43640f937373599(_jc_env *, struct _jc_gnu_java_nio_SelectionKeyImpl$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_nio_SelectionKeyImpl$method_info$channel$e64fdc027b0f082f;
extern _jc_method _jc_gnu_java_nio_SelectionKeyImpl$method_info$getNativeFD$4ed008ed25fb0a89;
extern _jc_method _jc_gnu_java_nio_SelectionKeyImpl$method_info$interestOps$03e920958ba95510;
extern _jc_method _jc_gnu_java_nio_SelectionKeyImpl$method_info$interestOps$0d8b00b560cc9fa0;
extern _jc_method _jc_gnu_java_nio_SelectionKeyImpl$method_info$readyOps$a69042b12a540927;
extern _jc_method _jc_gnu_java_nio_SelectionKeyImpl$method_info$readyOps$ac2951c8f6f38728;
extern _jc_method _jc_gnu_java_nio_SelectionKeyImpl$method_info$selector$d43640f937373599;

// Virtual methods structure
struct _jc_gnu_java_nio_SelectionKeyImpl$vmethods {
	struct _jc_java_nio_channels_SelectableChannel$object	*(*channel$e64fdc027b0f082f)(_jc_env *, struct _jc_gnu_java_nio_SelectionKeyImpl$object *) _JC_JCNI_ATTR;
	jint	(*getNativeFD$4ed008ed25fb0a89)(_jc_env *, struct _jc_gnu_java_nio_SelectionKeyImpl$object *) _JC_JCNI_ATTR;
	jint	(*interestOps$03e920958ba95510)(_jc_env *, struct _jc_gnu_java_nio_SelectionKeyImpl$object *) _JC_JCNI_ATTR;
	struct _jc_java_nio_channels_SelectionKey$object	*(*interestOps$0d8b00b560cc9fa0)(_jc_env *, struct _jc_gnu_java_nio_SelectionKeyImpl$object *, jint) _JC_JCNI_ATTR;
	jint	(*readyOps$a69042b12a540927)(_jc_env *, struct _jc_gnu_java_nio_SelectionKeyImpl$object *) _JC_JCNI_ATTR;
	struct _jc_java_nio_channels_SelectionKey$object	*(*readyOps$ac2951c8f6f38728)(_jc_env *, struct _jc_gnu_java_nio_SelectionKeyImpl$object *, jint) _JC_JCNI_ATTR;
	struct _jc_java_nio_channels_Selector$object	*(*selector$d43640f937373599)(_jc_env *, struct _jc_gnu_java_nio_SelectionKeyImpl$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_nio_SelectionKeyImpl$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_channels_SelectionKey$vmethods	java_nio_channels_SelectionKey;
	_jc_java_nio_channels_spi_AbstractSelectionKey$vmethods	java_nio_channels_spi_AbstractSelectionKey;
	_jc_gnu_java_nio_SelectionKeyImpl$vmethods	gnu_java_nio_SelectionKeyImpl;
};

// Vtype
struct _jc_gnu_java_nio_SelectionKeyImpl$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_SelectionKeyImpl$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_SelectionKeyImpl$sub_refs {
	struct _jc_gnu_java_nio_SelectorImpl$object	*impl;
	struct _jc_java_nio_channels_SelectableChannel$object	*ch;
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_SelectionKeyImpl$refs {
    _jc_gnu_java_nio_SelectionKeyImpl$sub_refs	gnu_java_nio_SelectionKeyImpl;
    _jc_java_nio_channels_spi_AbstractSelectionKey$sub_refs	java_nio_channels_spi_AbstractSelectionKey;
    _jc_java_nio_channels_SelectionKey$sub_refs	java_nio_channels_SelectionKey;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_SelectionKeyImpl$sub_nonrefs {
	jint	readyOps;
	jint	interestOps;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_SelectionKeyImpl$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_channels_SelectionKey$sub_nonrefs	java_nio_channels_SelectionKey;
    _jc_java_nio_channels_spi_AbstractSelectionKey$sub_nonrefs	java_nio_channels_spi_AbstractSelectionKey;
    _jc_gnu_java_nio_SelectionKeyImpl$sub_nonrefs	gnu_java_nio_SelectionKeyImpl;
};

// Object instance structure
struct _jc_gnu_java_nio_SelectionKeyImpl$object {
	_jc_gnu_java_nio_SelectionKeyImpl$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_SelectionKeyImpl$vtype	*vtype;
	_jc_gnu_java_nio_SelectionKeyImpl$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_SelectionKeyImpl$vtype _jc_gnu_java_nio_SelectionKeyImpl$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_SelectionKeyImpl, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_SelectionKeyImpl$class_object;

#endif	/* _JC_gnu_java_nio_SelectionKeyImpl_H_ */
